package java.net;

import java.io.IOException;

public class DatagramSocket {
   DatagramSocketImpl impl;
   static Class implClass;

   public DatagramSocket() throws SocketException {
      this.create(0, (InetAddress)null);
   }

   public DatagramSocket(int var1) throws SocketException {
      this(var1, (InetAddress)null);
   }

   public DatagramSocket(int var1, InetAddress var2) throws SocketException {
      if (var1 >= 0 && var1 <= 65535) {
         this.create(var1, var2);
      } else {
         throw new IllegalArgumentException("Port out of range:" + var1);
      }
   }

   void create(int var1, InetAddress var2) throws SocketException {
      SecurityManager var3 = System.getSecurityManager();
      if (var3 != null) {
         var3.checkListen(var1);
      }

      try {
         this.impl = (DatagramSocketImpl)implClass.newInstance();
      } catch (Exception var4) {
         throw new SocketException("can't instantiate DatagramSocketImpl");
      }

      this.impl.create();
      if (var2 == null) {
         var2 = InetAddress.anyLocalAddress;
      }

      this.impl.bind(var1, var2);
   }

   public void send(DatagramPacket var1) throws IOException {
      SecurityManager var2 = System.getSecurityManager();
      synchronized(var1){}

      try {
         if (var2 != null) {
            if (var1.getAddress().isMulticastAddress()) {
               var2.checkMulticast(var1.getAddress());
            } else {
               var2.checkConnect(var1.getAddress().getHostAddress(), var1.getPort());
            }
         }

         this.impl.send(var1);
      } catch (Throwable var5) {
         throw var5;
      }

   }

   public synchronized void receive(DatagramPacket var1) throws IOException {
      SecurityManager var2 = System.getSecurityManager();
      synchronized(var1){}

      try {
         if (var2 != null) {
            while(true) {
               InetAddress var5 = new InetAddress();
               int var6 = this.impl.peek(var5);

               try {
                  var2.checkConnect(var5.getHostAddress(), var6);
                  break;
               } catch (SecurityException var10) {
                  DatagramPacket var7 = new DatagramPacket(new byte[1], 1);
                  this.impl.receive(var7);
               }
            }
         }

         this.impl.receive(var1);
      } catch (Throwable var11) {
         throw var11;
      }

   }

   public InetAddress getLocalAddress() {
      Object var1 = null;

      try {
         var4 = (InetAddress)this.impl.getOption(15);
         SecurityManager var2 = System.getSecurityManager();
         if (var2 != null) {
            var2.checkConnect(var4.getHostAddress(), -1);
         }
      } catch (Exception var3) {
         var4 = InetAddress.anyLocalAddress;
      }

      return var4;
   }

   public int getLocalPort() {
      return this.impl.getLocalPort();
   }

   public synchronized void setSoTimeout(int var1) throws SocketException {
      this.impl.setOption(4102, new Integer(var1));
   }

   public synchronized int getSoTimeout() throws SocketException {
      Object var1 = this.impl.getOption(4102);
      return var1 instanceof Integer ? (Integer)var1 : 0;
   }

   public void close() {
      this.impl.close();
   }

   static {
      String var0 = "";

      try {
         SecurityManager.enablePrivilege("UniversalPropertyRead");
         var0 = System.getProperty("impl.prefix", "Plain");
         implClass = Class.forName("java.net." + var0 + "DatagramSocketImpl");
      } catch (Exception var2) {
         System.err.println("Can't find class: java.net." + var0 + "DatagramSocketImpl: check impl.prefix property");
      }

      if (implClass == null) {
         try {
            implClass = Class.forName("java.net.PlainDatagramSocketImpl");
         } catch (Exception var1) {
            throw new Error("System property impl.prefix incorrect");
         }
      }
   }
}
