package java.net;

import java.io.FileDescriptor;
import java.io.IOException;

class PlainDatagramSocketImpl extends DatagramSocketImpl {
   private int timeout;

   protected synchronized void create() throws SocketException {
      super.fd = new FileDescriptor();
      this.datagramSocketCreate();
   }

   protected synchronized native void bind(int var1, InetAddress var2) throws SocketException;

   protected native void send(DatagramPacket var1) throws IOException;

   protected synchronized native int peek(InetAddress var1) throws IOException;

   protected synchronized native void receive(DatagramPacket var1) throws IOException;

   protected native void setTTL(byte var1) throws IOException;

   protected native byte getTTL() throws IOException;

   protected native void join(InetAddress var1) throws IOException;

   protected native void leave(InetAddress var1) throws IOException;

   protected void close() {
      if (super.fd != null) {
         this.datagramSocketClose();
         super.fd = null;
      }

   }

   protected synchronized void finalize() {
      this.close();
   }

   public void setOption(int var1, Object var2) throws SocketException {
      switch (var1) {
         case 4:
            if (var2 == null || !(var2 instanceof Integer)) {
               throw new SocketException("bad argument for SO_REUSEADDR");
            }
            break;
         case 15:
            throw new SocketException("Cannot re-bind Socket");
         case 16:
            if (var2 == null || !(var2 instanceof InetAddress)) {
               throw new SocketException("bad argument for IP_MULTICAST_IF");
            }
            break;
         case 4102:
            if (var2 != null && var2 instanceof Integer) {
               int var3 = (Integer)var2;
               if (var3 < 0) {
                  throw new IllegalArgumentException("timeout < 0");
               }

               this.timeout = var3;
               return;
            }

            throw new SocketException("bad argument for SO_TIMEOUT");
         default:
            throw new SocketException("invalid option: " + var1);
      }

      this.socketSetOption(var1, var2);
   }

   public Object getOption(int var1) throws SocketException {
      if (var1 == 4102) {
         return new Integer(this.timeout);
      } else {
         int var2 = this.socketGetOption(var1);
         if (var1 != 15 && var1 != 16) {
            return null;
         } else {
            InetAddress var3 = new InetAddress();
            var3.address = var2;
            return var3;
         }
      }
   }

   private native void datagramSocketCreate() throws SocketException;

   private native void datagramSocketClose();

   private native void socketSetOption(int var1, Object var2) throws SocketException;

   private native int socketGetOption(int var1) throws SocketException;

   static {
      SecurityManager.enablePrivilege("UniversalLinkAccess");
      System.loadLibrary("net");
   }
}
